==> haskell-regex-compat-tdfa-0.95.1.4-204-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-regex-compat-tdfa.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 regex-compat-tdfa
version:              0.95.1.4
visibility:           public
id:                   regex-compat-tdfa-0.95.1.4-69V1Y3M1bXQ4u5mywzPtA5
key:                  regex-compat-tdfa-0.95.1.4-69V1Y3M1bXQ4u5mywzPtA5
license:              BSD-3-Clause
copyright:
    Copyright (c) Christopher Kuklewicz 2006
    (c) shelarcy 2012

maintainer:           shelarcy <shelarcy@gmail.com>
author:               Christopher Kuklewicz
stability:            Seems to work, passes a few tests
homepage:             http://hub.darcs.net/shelarcy/regex-compat-tdfa
package-url:          http://hackage.haskell.org/package/regex-compat-tdfa
synopsis:             Unicode Support version of Text.Regex, using regex-tdfa
description:
    One module layer over regex-tdfa to replace Text.Regex.

    regex-compat can'\''t use Unicode characters correctly because
    of using regex-posix. This is not good for Unicode users.

    I modified regex-compat to use regex-tdfa for solving today'\''s
    problem.

category:             Text
abi:                  a87b4df904e2e81bfc889aeca3e86f09
exposed:              True
exposed-modules:      Text.Regex
import-dirs:          /usr/lib/ghc-9.2.8/site-local/regex-compat-tdfa-0.95.1.4
library-dirs:         /usr/lib/ghc-9.2.8/site-local/regex-compat-tdfa-0.95.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-regex-compat-tdfa
hs-libraries:         HSregex-compat-tdfa-0.95.1.4-69V1Y3M1bXQ4u5mywzPtA5
depends:
    array-0.5.4.0 base-4.16.4.0
    regex-base-0.94.0.2-6On48UZuN5IJxnL3aRqiWN
    regex-tdfa-1.3.2.2-BoNTNKUNKmp8we6nhxSrFQ

haddock-interfaces:
    /usr/share/doc/haskell-regex-compat-tdfa/html/regex-compat-tdfa.haddock

haddock-html:         /usr/share/doc/haskell-regex-compat-tdfa/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-regex-compat-tdfa-0.95.1.4-245.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-regex-compat-tdfa.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 regex-compat-tdfa
version:              0.95.1.4
visibility:           public
id:                   regex-compat-tdfa-0.95.1.4-32pN93pMmqE4SZPjBJJ9xD
key:                  regex-compat-tdfa-0.95.1.4-32pN93pMmqE4SZPjBJJ9xD
license:              BSD-3-Clause
copyright:
    Copyright (c) Christopher Kuklewicz 2006
    (c) shelarcy 2012

maintainer:           shelarcy <shelarcy@gmail.com>
author:               Christopher Kuklewicz
stability:            Seems to work, passes a few tests
homepage:             http://hub.darcs.net/shelarcy/regex-compat-tdfa
package-url:          http://hackage.haskell.org/package/regex-compat-tdfa
synopsis:             Unicode Support version of Text.Regex, using regex-tdfa
description:
    One module layer over regex-tdfa to replace Text.Regex.

    regex-compat can'\''t use Unicode characters correctly because
    of using regex-posix. This is not good for Unicode users.

    I modified regex-compat to use regex-tdfa for solving today'\''s
    problem.

category:             Text
abi:                  348c6722ab203b0ab52b53580dc93102
exposed:              True
exposed-modules:      Text.Regex
import-dirs:          /usr/lib/ghc-9.4.8/site-local/regex-compat-tdfa-0.95.1.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/regex-compat-tdfa-0.95.1.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/regex-compat-tdfa-0.95.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-regex-compat-tdfa
hs-libraries:         HSregex-compat-tdfa-0.95.1.4-32pN93pMmqE4SZPjBJJ9xD
depends:
    array-0.5.4.0 base-4.17.2.1
    regex-base-0.94.0.3-4CB0YhYwj75B1BjBDOnQyh
    regex-tdfa-1.3.2.4-LXwWfM9riXbAuaKHkk8lra

haddock-interfaces:
    /usr/share/doc/haskell-regex-compat-tdfa/html/regex-compat-tdfa.haddock

haddock-html:         /usr/share/doc/haskell-regex-compat-tdfa/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
